@@ -52,12 +52,12 @@ onOK <- function(){
                as.logical(as.numeric(tclvalue(replacecbVariable))),")",sep="")
            else{
               if (tclvalue(decimalrbVariable)=="default") command <- paste("add.response(",name,
-                     ", ",dQuote(csvpath),", replace=",
+                     ", ",dquote(csvpath),", replace=",
                      as.logical(as.numeric(tclvalue(replacecbVariable))),")",sep="")
               else command <- paste("add.response(",name, 
-                     ", ",dQuote(csvpath),", replace=",
+                     ", ",dquote(csvpath),", replace=",
                      as.logical(as.numeric(tclvalue(replacecbVariable))),", InDec=", 
-                     dQuote(tclvalue(decimalrbVariable)),")",sep="")
+                     dquote(tclvalue(decimalrbVariable)),")",sep="")
                }
         hilf <- justDoItDoE(command)
         if (class(hilf)[1]=="try-error"){
@@ -87,12 +87,18 @@ dquote <- function(obj){
     aus <- rep("",length(obj))
     wopt <- options("warn")[[1]]
     options(warn=-1)
-    for (i in 1:length(obj)) if (is.na(as.numeric(obj[i]))) aus[i] <- paste('"',obj[i],'"',sep="") 
+    for (i in 1:length(obj)) if (is.na(as.numeric(obj[i]))) {
+            if (length(grep('"',obj[i])>0))
+            aus[i] <- paste("'",obj[i],"'",sep="") 
+            else
+            aus[i] <- paste('"',obj[i],'"',sep="") 
+            }
           else aus[i] <- obj[i]
     options(warn=wopt)
     aus
 }
 
+
  onRadio <- function(){
     if (tclvalue(etyperbVariable)=="R"){
         tkconfigure(dirEntry, state="disabled")
